@@ -3,6 +3,6 @@
 
 int mainw()
 {
-  system("Spectral-GEM_Rv1.2.exe < tmp00001.txt");
+  system("SpectralGEM_v2.1.exe < tmp00001.txt");
   system("rm -f tmp00001.txt");
 }
